@@ -16,12 +16,6 @@ documentation.
  * @brief Contains the pbf_reader class.
  */
 
-#include <cstddef>
-#include <cstdint>
-#include <cstring>
-#include <string>
-#include <utility>
-
 #include <protozero/config.hpp>
 #include <protozero/data_view.hpp>
 #include <protozero/exception.hpp>
@@ -33,6 +27,12 @@ documentation.
 # include <protozero/byteswap.hpp>
 #endif
 
+#include <cstddef>
+#include <cstdint>
+#include <cstring>
+#include <string>
+#include <utility>
+
 namespace protozero {
 
 /**
@@ -117,9 +117,9 @@ class pbf_reader {
         }
         m_data += len;
 
-    // In debug builds reset the tag to zero so that we can detect (some)
-    // wrong code.
 #ifndef NDEBUG
+        // In debug builds reset the tag to zero so that we can detect (some)
+        // wrong code.
         m_tag = 0;
 #endif
     }
@@ -241,7 +241,7 @@ public:
      * are still fields available and to `false` if the last field has been
      * read.
      */
-    operator bool() const noexcept { // NOLINT clang-tidy: google-explicit-constructor
+    operator bool() const noexcept { // NOLINT(google-explicit-constructor, hicpp-explicit-conversions)
         return m_data < m_end;
     }
 
@@ -279,7 +279,7 @@ public:
         }
 
         const auto value = get_varint<uint32_t>();
-        m_tag = pbf_tag_type(value >> 3);
+        m_tag = pbf_tag_type(value >> 3u);
 
         // tags 0 and 19000 to 19999 are not allowed as per
         // https://developers.google.com/protocol-buffers/docs/proto#assigning-tags
@@ -287,7 +287,7 @@ public:
             throw invalid_tag_exception{};
         }
 
-        m_wire_type = pbf_wire_type(value & 0x07);
+        m_wire_type = pbf_wire_type(value & 0x07u);
         switch (m_wire_type) {
             case pbf_wire_type::varint:
             case pbf_wire_type::fixed64:
